package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````T!]```````!``````````!#'````
M`````````$``.``(`$``&@`9``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````,RW````````S+<`````````
M`"````````$````&`````,``````````P&````````#`8```````1`0`````
M``"H"0``````````(````````@````8````HP````````"C`8```````*,!@
M``````#P`0```````/`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````@+,```````"`LT```````("S0```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`(B_#0!A````9@```````````````````#D`````
M````*P```&,````B``````````````!.`````````%(```!,`````````#0`
M```\````80````(````M````50```%X````V````.@``````````````'0``
M`$L````D````5``````````J````7P```$T````+`````````&````!B````
M)P```&4`````````/0````````!1````6@```%,```!=```````````````&
M````'````!(````C````+P````H````X````/P```$,```!;`````````$0`
M```^`````````%``````````````````````````5@```"@````7````2@``
M`"P```!!`````````````````````P```!L````%````9````%P```!"````
M`````!\````)````````````````````0`````````!7````#P````````!%
M````1@```````````````````````````````0``````````````````````
M````````````````````````````````````````#0``````````````````
M```````````````````````````````````````````````````````:````
M````````````````&0````@````1````````````````````%`````P````.
M`````````!4````E```````````````````````````````8````````````
M````````````````````````````````````````(````!,`````````````
M```````P````,@``````````````*0`````````>````%@```"8```!)````
M`````#,`````````(0```$\````N````````````````````````````````
M````-0```#<`````````!````$<```!(````$````%@``````````````#$`
M```[````60````<`````````````````````````````````````````A0$`
M`!(``````````````"$!````````K`,``!(`#``0/$````````4`````````
MO0,``!(`#`#@($```````#0`````````#````!(``````````````!4`````
M````(@0``!(``````````````!X`````````>@,``!(`#`#0'T```````)P`
M````````%@```!(``````````````&$%````````C`(``!(`````````````
M````````````(0```!$`%P!@Q&````````$`````````/@(``!(`````````
M`````*P`````````.````"``````````````````````````@0(``!$`%@`@
MQ&````````@`````````3````!(`#0!45$``````````````````R@,``!(`
M#`!P4$```````%(#````````X`,``!(`#`!@.$```````$T`````````[@,`
M`!(`#`!`.T```````,D`````````4@```!(``````````````#L$````````
M6P```!$`%P!PQ&````````$`````````9@```!(``````````````/``````
M````=````!(``````````````$(`````````!`0``!(`#`!`04```````.(`
M````````$`0``!(`#``004```````"(`````````A````!$`%P"`Q&``````
M``$`````````D@```!(``````````````&$!````````R`(``!(`````````
M`````"\`````````]@(``!(```````````````P`````````*P0``!(`#``P
M0D```````&T`````````9P,``!(```````````````\`````````#@,``!(`
M````````````````````````6`,``!(``````````````&P`````````H```
M`!$`%P"0Q&````````@`````````10,``!(`````````````````````````
MJ@```!(``````````````"L`````````'`,``!(```````````````(`````
M````M0```!(```````````````H#````````8`,``!(``````````````%4`
M````````+0,``!(``````````````-D`````````PP```!$`%P"8Q&``````
M``@`````````-0,``!(``````````````)``````````2`(``!(`````````
M`````$H`````````R0```!(``````````````!4`````````P@(``!(`````
M`````````&<`````````UP```!$`%P"@Q&````````@`````````LP(``!(`
M`````````````/0`````````Y````!(```"$'4```````,X!````````0P(`
M`!(``````````````'$`````````]````!$`%P"HQ&````````$`````````
M_P```!(```````````````\!````````$`$``!(``````````````*H'````
M````/0,``!(``````````````"$`````````1`,``!(`````````````````
M````````'P$``!$`%P"PQ&````````@`````````)@,``!(`````````````
M````````````I0(``!(`````````````````````````GP(``!(`````````
M````````````````-P0``!(`#`#04T```````!0`````````JP(``!(`````
M`````````#0`````````+P$``!(``````````````&@!````````/@$``!(`
M`````````````)$"````````3`$``!(``````````````!\:````````SP(`
M`!(`````````````````````````!@,``!(``````````````$P`````````
MY0(``!(```````````````P`````````=0,``!``\?]$Q&``````````````
M````6@$``!$`%P"@R6````````@`````````8@$``!(``````````````.0`
M````````>0(``!(``````````````(\0````````3@(``!(`````````````
M`#$`````````N@(``!(```````````````H`````````<@(``!(`````````
M`````$H`````````;@$``!$`%P"XQ&````````@`````````/P0``!(`#`"P
M.$```````!X`````````8`(``!$`%P#`Q&```````$``````````2@,``!(`
M`````````````'P`````````@0,``!``\?^HR6``````````````````U@(`
M`!(`````````````````````````%0,``!(``````````````%0`````````
M>0$``!(``````````````#8`````````C`$``!(``````````````)``````
M````F0$``!$`%P``Q6````````$`````````I@$``!$`%P`0Q6```````!,`
M````````R@(``!(``````````````"\`````````6P0``!(`#`!`1D``````
M`"P*````````M0$``!(``````````````(T`````````;@,``!``\?]$Q&``
M````````````````$0```!(```````````````T'````````P`$``!(`````
M`````````,4"````````:`0``!(`#``P/D```````!<!````````>@0``!(`
M#`"01$```````*P!````````AP0``!$`%@`XQ&````````@`````````RP$`
M`!(``````````````&<`````````W0(``!(``````````````$H`````````
M_0(``!(``````````````)L`````````E0(``!$`%P!`Q6````````@`````
M````40,``!(``````````````'X`````````D00``!(`#`!0/T```````+X!
M````````G@0``!(`#`"@0D```````/`!````````.00``!(`"@#`&T``````
M````````````V@$``!$`%P!(Q6````````@`````````Y`$``!(`````````
M`````'P`````````^P$``!(``````````````)T(`````````&QI8G!E<FPN
M<V\`<&5R;%]F<F5E`'!E<FQ?<&%R<V4`4$Q?<&5R;%]D97-T<G5C=%]L979E
M;`!?2G9?4F5G:7-T97)#;&%S<V5S`%]F:6YI`'!E<FQ?<G5N`%!,7VEN7V5V
M86P`4&5R;%]A=E]S:&EF=`!097)L7V=V7V9E=&-H<'8`4$Q?97AI=%]F;&%G
M<P!097)L7W-V7W-E='!V`%!,7V-O;7!C=@!P97)L7V%L;&]C`%!E<FQ?9&]U
M;G=I;F0`4$Q?;W``4&5R;%]S>7-?=&5R;0!03%]E=F%L7W)O;W0`8F]O=%]$
M>6YA3&]A9&5R`%!,7W1A:6YT960`4&5R;%]N97=84U]F;&%G<P!P97)L7V-O
M;G-T<G5C=`!03%]C=7)S=&%C:VEN9F\`4&5R;%]S=E]S971P=FX`4&5R;%]A
M=E]F971C:`!P97)L7V1E<W1R=6-T`&5N=FER;VX`4&5R;%]M9U]S970`4$Q?
M=&]P7V5N=@!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]N97=35G!V`%!,7V1O
M7W5N9'5M<`!03%]M96UO<GE?=W)A<`!097)L7V-R;V%K`%!E<FQ?;F5W6%,`
M4&5R;%]S>7-?:6YI=#,`4$Q?<&%R<V5R`%!E<FQ?<V%V95]D97-T<G5C=&]R
M7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB;2YS;RXU`&QI8F-R>7!T+G-O+C4`
M;&EB=71I;"YS;RXY`&QI8G1H<BYS;RXS`&]P96X`<F5A9`!C;&]S90!?7V5R
M<F]R`&QI8F,N<V\N-P!?7W-T86-K7V-H:U]G=6%R9`!M96UC<'D`<F5A;&QO
M8P!?7W!R;V=N86UE`')E861L:6YK`%]?<W1D97)R<`!R;61I<@!M:V1I<@!S
M=')N8VUP`'-T<FQE;@!O<&5N9&ER`&QS965K`&%T97AI=`!A8V-E<W,`9V5T
M<&ED`&UE;6UO=F4`7U]S=&%C:U]C:&M?9F%I;`!S=')T;VL`8VQO<V5D:7(`
M<W1R;F-P>0!U;FQI;FL`;65M<V5T`%]I;FET7W1L<P!G971U:60`9G!R:6YT
M9@!S<')I;G1F`&UE;6-H<@!L<W1A=`!S=')S='(`<W1R8VUP`')E861D:7(`
M<W1R9'5P`&5X96-V<`!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQO
M8V%L+VQI8B]P97)L-2\U+C$T+C(O;6%C:"]#3U)%`'!A<E]C=7)R96YT7V5X
M96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV
M7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!X<U]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!P87)?;6MT;7!D:7(`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E
M;G8`;6%I;@!&0E-$7S$N,`````(``0`!`````@`!`````@````,````!``$`
M`0`!``$````````````!``$```````(``@`!``(``@`"`````@````(````"
M``(````"``,````"`````@````,``````````@`"`````@`"``(``0`"````
M``````(``@`"``$``0````(``P`"``(````!``(``@`!``(``@``````````
M``(``0````$``@````$``0`!`````@`"``(``@`!``$``0`````````!``$`
M,@(``!`````@````L"AZ!P```P"C!`````````$``0!6`@``$`````````"P
M*'H'```"`*,$````````8,1@```````%````"0``````````````<,1@````
M```%````$@``````````````@,1@```````%````%P``````````````D,1@
M```````%````'P``````````````F,1@```````%````)@``````````````
MH,1@```````%````*P``````````````J,1@```````%````+P``````````
M````L,1@```````%````-```````````````N,1@```````%````1P``````
M````````P,1@```````%````20```````````````,5@```````%````4```
M````````````$,5@```````%````40``````````````0,5@```````%````
M7@``````````````2,5@```````%````8P``````````````,,)@```````'
M`````0``````````````.,)@```````'````!```````````````0,)@````
M```'````!0``````````````2,)@```````'````!P``````````````4,)@
M```````'````"```````````````6,)@```````'````"@``````````````
M8,)@```````'````$0``````````````:,)@```````'````$P``````````
M````<,)@```````'````%```````````````>,)@```````'````&```````
M````````@,)@```````'````&0``````````````B,)@```````'````&@``
M````````````D,)@```````'````'```````````````F,)@```````'````
M'0``````````````H,)@```````'````'@``````````````J,)@```````'
M````(```````````````L,)@```````'````(0``````````````N,)@````
M```'````(@``````````````P,)@```````'````(P``````````````R,)@
M```````'````)```````````````T,)@```````'````)0``````````````
MV,)@```````'````)P``````````````X,)@```````'````*```````````
M````Z,)@```````'````*0``````````````\,)@```````'````*@``````
M````````^,)@```````'````+````````````````,-@```````'````+0``
M````````````",-@```````'````+@``````````````$,-@```````'````
M,```````````````&,-@```````'````,0``````````````(,-@```````'
M````,@``````````````*,-@```````'````,P``````````````,,-@````
M```'````-0``````````````.,-@```````'````-@``````````````0,-@
M```````'````-P``````````````2,-@```````'````.0``````````````
M4,-@```````'````.@``````````````6,-@```````'````.P``````````
M````8,-@```````'````/```````````````:,-@```````'````/0``````
M````````<,-@```````'````/@``````````````>,-@```````'````/P``
M````````````@,-@```````'````0@``````````````B,-@```````'````
M0P``````````````D,-@```````'````1```````````````F,-@```````'
M````10``````````````H,-@```````'````1@``````````````J,-@````
M```'````2@``````````````L,-@```````'````3```````````````N,-@
M```````'````30``````````````P,-@```````'````3@``````````````
MR,-@```````'````3P``````````````T,-@```````'````4@``````````
M````V,-@```````'````5```````````````X,-@```````'````5@``````
M````````Z,-@```````'````5P``````````````\,-@```````'````6P``
M````````````^,-@```````'````7````````````````,1@```````'````
M70``````````````",1@```````'````7P``````````````$,1@```````'
M````9```````````````&,1@```````'````90``````````````2(/L".CG
M!```Z%(X``!(@\0(PP#_-4:F(`#_)4BF(``/'T``_R5&IB``:`````#IX/__
M__\E/J8@`&@!````Z=#_____)3:F(`!H`@```.G`_____R4NIB``:`,```#I
ML/____\E)J8@`&@$````Z:#_____)1ZF(`!H!0```.F0_____R46IB``:`8`
M``#I@/____\E#J8@`&@'````Z7#_____)0:F(`!H"````.E@_____R7^I2``
M:`D```#I4/____\E]J4@`&@*````Z4#_____)>ZE(`!H"P```.DP_____R7F
MI2``:`P```#I(/____\EWJ4@`&@-````Z1#_____)=:E(`!H#@```.D`____
M_R7.I2``:`\```#I\/[___\EQJ4@`&@0````Z>#^____);ZE(`!H$0```.G0
M_O___R6VI2``:!(```#IP/[___\EKJ4@`&@3````Z;#^____)::E(`!H%```
M`.F@_O___R6>I2``:!4```#ID/[___\EEJ4@`&@6````Z8#^____)8ZE(`!H
M%P```.EP_O___R6&I2``:!@```#I8/[___\E?J4@`&@9````Z5#^____)7:E
M(`!H&@```.E`_O___R5NI2``:!L```#I,/[___\E9J4@`&@<````Z2#^____
M)5ZE(`!H'0```.D0_O___R56I2``:!X```#I`/[___\E3J4@`&@?````Z?#]
M____)4:E(`!H(````.G@_?___R4^I2``:"$```#IT/W___\E-J4@`&@B````
MZ<#]____)2ZE(`!H(P```.FP_?___R4FI2``:"0```#IH/W___\E'J4@`&@E
M````Z9#]____)1:E(`!H)@```.F`_?___R4.I2``:"<```#I</W___\E!J4@
M`&@H````Z6#]____)?ZD(`!H*0```.E0_?___R7VI"``:"H```#I0/W___\E
M[J0@`&@K````Z3#]____)>:D(`!H+````.D@_?___R7>I"``:"T```#I$/W_
M__\EUJ0@`&@N````Z0#]____)<ZD(`!H+P```.GP_/___R7&I"``:#````#I
MX/S___\EOJ0@`&@Q````Z=#\____);:D(`!H,@```.G`_/___R6NI"``:#,`
M``#IL/S___\EIJ0@`&@T````Z:#\____)9ZD(`!H-0```.F0_/___R66I"``
M:#8```#I@/S___\ECJ0@`&@W````Z7#\____)8:D(`!H.````.E@_/___R5^
MI"``:#D```#I4/S___\E=J0@`&@Z````Z4#\____)6ZD(`!H.P```.DP_/__
M_R5FI"``:#P```#I(/S___\E7J0@`&@]````Z1#\__\```````````````!5
M2(GE055,C6\(05132(/L"(L?2&/#A=M,C63'$$R)):RI(`!^.DB+5PA(A=)T
M,4B)%1JD(``/M@*$P'0C2(/"`3PO2(L%!J0@`$@/1,)(B07[HR``#[8"2(/"
M`83`=>&X*,!@`$B%P'0K2(GWZ$+\__^_5%1``.@X_/__Z&_[__^)WTR)XDR)
M[NA"(@``B<?HO_[__^B*_/__Z]:0D)"0@#W9I"```%5(B>5T$.LDD$B#P`A(
MB06EHR``_])(BP6<HR``2(L02(72=>3&!:VD(``!R<,/'T0``&8/'T0``%5(
M@SUGGR```$B)Y706N`````!(A<!T#+\@P&``28G#R4'_X\G#D)"0D)"0D)"0
MD`^V#TB)^(3)="A(BP6/-0``2(U7`0^V,$B)^`\?1```0#CQ#[8*2`]$PDB#
MP@&$R77N\\-F#Q]$``!F#Q]$``!!5DB-=SA!54%454B)_5-(@>P(`@``3(U,
M)(A-C8&`````3(G/2(L.2(/&"$B)RDB)R$C!X@A(P>`8)0```/^!X@``_P!(
M"<)(B<A(P>@()0#_``!("<)(B<A(P>@8)?\```!("<)(B<A(P>DH2,'H($B)
M%TC!X`A(B<)(P>`0)0```/^!X@``_P!("<)(B<A(P>D0)0#_``!("<)("<I(
MB5<(2(/'$$PYQP^%=?___TF-26A)C;%H`@``#Q]$``!(BP%(,T'82#-!J$@S
M09A(B<)(`<!(P>H?2`G"@^+_2(E1&$B#P0A(.?%UU$R+=0!(BWPDB$&]W+P;
MCT@#?2!(BTT(3(M5$$B+=1A,B?!,B?)-B?%(P>(%2,'H&TF)R$@)T$R)TDG!
MZ`*#X/]((<I)P>D"2(V\!YEY@EI(B<A(P>$>2/?020G(2"'P08/@_T@#="20
M2`G03(G"`<=,B?!,(?)(]]!(B?E,(=!(P>D;3`-4))A("<)(B?A(P>`%2(VT
M%IEY@EI(B?I("<%,B?!(P>`>`?%)"<%(B?A(B<Y!@^'_2/?02,'N&TPARDPA
MP$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DCWT$G!Z@)(P><>
M3`-$)*!)"?I,(<A(B?=!@^+_2,'O&TP#3"2H3"'22`G02(GR38V$`)EY@EI(
MB?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I
M&TP#5"2P3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F
M'DG!Z0)(]]!)"?%,(<!(B<Y!@^'_2,'N&TPARD@)T$B)RDV-E`*9>8):2(G(
M2,'@!4P#1"2X2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)"?I,(<A(B?=!@^+_
M2,'O&TP#3"3`3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(
M2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TP#5"3(3"'"2`G02(GZ38V,
M`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)"?%,(<!(B<Y!
M@^'_3"'*2,'N&TP#1"302`G02(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'6
M28GZ2,'G'DG!Z@)(]]!)"?I,(<A(B?=!@^+_2,'O&TP#3"383"'22`G02(GR
M38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(
MB?E!@^#_2,'I&TPAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)
M\4C!YAY)P>D"2/?020GQ2(G.08/A_TP#5"3@3"'`3"'*2,'N&TP#1"3H2`G0
M2(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)"?I,
M(<A(B?=!@^+_2,'O&TP#3"3P3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'
M2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)
M^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4CWT$G!Z0)(P>8>3`-4)/A)
M"?%,(<!(B<Y!@^'_2,'N&TP#!"1,(<I("=!(B<I-C90"F7F"6DB)R$C!X`5(
M"<9(B<A$`=9)B?I(P><>2<'J`DCWT$F)\TD)^DPAR$B)]T&#XO](P>\;3`-,
M)`A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H
M`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%
M2,'F'DG!ZP),`U0D$$@)P4D)\TB)^$&#X_]$`<E(]]!,(=I(B<Y,(<!)B?E(
MP>X;2`G02,'G'DG!Z0)-C90"F7F"6DB)R$P#1"082,'@!4D)^4B)RD@)QDB)
MR$&#X?](]]!,(<I$`=9,(=A(B?=)B<I("=!(P>$>2,'O&TV-A`"9>8):2(GP
M2<'J`DC!X`5,`UPD($D)RD@)QTB)\$&#XO](B?)(]]!$`<=,(<A)B?!,(=)(
M"=!(P>8>2<'H`DV-G`.9>8):20GP2(GZ2(GX08/@_TP#3"0H2,'@!4C!ZAM(
M"<),B<!,,=!$`=I,`U0D,$@Q^$B)T4V-C`&AZ]EN2(G02,'I&TC!X`5("<%$
M`<E)B?E(P><>2<'I`DB)SDD)^4B)UTC![AM!@^'_2,'O`DR)R$PQP$P#1"0X
M2#'02,'B'DV-E`*AZ]EN2`G72(G(@^?_2,'@!4@)QDB)^$0!UDPQR$P#3"1`
M2#'(2(GR38V$`*'KV6Y(B?!(P>H;2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(
M2(G108/@_TC!Z1M,B<!(,?A(`WPD2$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!
MR4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`T0D4$@QT$B-O`>A
MZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](B?A,,<A(P>H;
M3`-,)%A(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(P>$>2<'H`DD)R$B)
MT4&#X/](P>D;3(G`2#'X2`-\)&!(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)
MB?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`-$)&A(,=!(C;P'H>O9
M;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#
M3"1P2#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!
M@^#_2,'I&TR)P$@Q^$@#?"1X2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ
M2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#A"2`````2#'02(V\!Z'K
MV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,
M`XPDB````$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(
M2(G108/@_TC!Z1M,B<!(,?A(`[PDD````$@Q\$V-C`&AZ]EN2(G02,'@!4@)
MP40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`X0DF````$@Q
MT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](B?A,
M,<A(P>H;3`.,)*````!(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(P>$>
M2<'H`DF)TDD)R$B)T4G!Z@)!@^#_2,'I&TR)P$@Q^$@#O"2H````2#'P38V,
M`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))B<Q)"?%(B<Y!@^'_2,'N
M&TR)R$PQP$P#A"2P````2#'02,'B'DB-O`>AZ]EN20G22(G(08/B_TC!X`5(
M"<9,B=`!_DPQR$G![`)(,<A(P>$>2(GR38V$`*'KV6Y)"<Q(B?!!@^3_3`.,
M)+@```!(P>`%2,'J&TB)\TB+C"3(````2`G"3(G@2,'K`DPQT$0!PDP#E"3`
M````2#'P2,'F'DB)UTV-C`&AZ]EN2`GS2(G0@^/_2,'@!4C![QM("<=(B=A)
MB=-,,>!$`<])P>L"2#'02,'B'DF)^$V-E`*AZ]EN20G32(GX08/C_TC!X`5)
MP>@;20G`3`'I3(G810'03(G:3`'A2`G82"':3(G&2"'X28GY2,'N&T@)T$C!
MYQY)P>D"2`'!3(G`20GY2,'@!4&#X?]-B<)("<9,B<A,B<H!SDB+C"30````
M3`G83"':3"'`2(GW2`G02,'O&TG!X!Y,`>E)P>H"0;S6P6+*2`'930G"2`'!
M2(GP08/B_TC!X`5,B=)("<=,B=`!STB+C"38````3`G(2"'P28GX3`'I3`'9
M3"'*28GS2`G02,'F'DG!Z!M(`<%(B?A)P>L"2,'@!4D)\TD)P$&#X_]!`<A(
MBXPDX````$R)V$P)T$R)VDR)QDPATD@A^$C![AM,`>E("=!,`<E)B?E(P><>
M2`'!3(G`2<'I`DC!X`5)"?E("<9!@^'_`<Y(BXPDZ````$R)R$P)V$R)RDB)
M]TPAVDPAP$P!Z4@)T$P!T4V)PD@!P4B)\$C![QM(P>`%2<'@'DG!Z@)("<=-
M"<(!ST&#XO](BXPD\````$R)T$R)TDF)^$P)R$PARDG!Z!M,`>E((?!("=!,
M`=E)B?-(`<%(B?A(P>8>2,'@!4G!ZP))"<!)"?-!`<A!@^/_2(N,)/@```!,
MB=A,B=I,B<9,"=!,(=)(P>X;3`'I2"'X2`G03`')28GY2`'!3(G`2,'@!4@)
MQ@'.2,'G'DG!Z0))"?E(BXPD``$``$B)]T&#X?](P>\;3(G(3(G*3`G83"':
M3`'I3"'`3`'138G"2`G02<'@'DG!Z@)(`<%(B?!-"<)(P>`%08/B_T@)QTR)
MT$R)T@'/2(N,)`@!``!,"<A,(<I((?!)B?A("=!)P>@;3`'I3`'928GS2,'F
M'D@!P4B)^$G!ZP)(P>`%20G`00'(20GS2(N,)!`!``!!@^/_3(G&3(G83(G:
M2,'N&TP)T$PATDP!Z4@A^$P!R4F)^4@)T$C!YQY)P>D"2`'!3(G`20GY2,'@
M!4&#X?]("<9,B<A,B<H!SDB+C"08`0``3`G83"':3"'`2(GW2`G02,'O&TP!
MZ4P!T4V)PDG!X!Y(`<%(B?!)P>H"2,'@!4T)PD@)QT&#XO\!STB+C"0@`0``
M3(G03(G228GX3`'I3`'93`G(3"'*2"'P28GS2<'H&T@)T$C!YAY)P>L"2`'!
M2(GX20GS2,'@!4&#X_])"<!,B=A,B=I!`<A(BXPD*`$``$P)T$PATD@A^$R)
MQD@)T$C![AM,`>E,`<E)B?E(P><>2`'!3(G`2<'I`DC!X`5)"?E("<9!@^'_
M`<Y(BXPD,`$``$R)R$P)V$R)RDB)]TPAP$P!Z4P!T4PAVDV)PD@)T$G!X!Y(
MP>\;2`'!2(GP2<'J`DC!X`5-"<)("<=!@^+_`<](BXPD.`$``$R)T$P)R$R)
MTDF)^$PARD@A\$G!Z!M,`>E("=!,`=E)B?-(P>8>2`'!2(GX2<'K`DC!X`5)
M"?-)"<!!@^/_00'(2(N,)$`!``!,B=A,"=!,B=I,B<9,(=)((?A,`>E("=!,
M`<E)B?E(`<%,B<!(P>X;2,'@!4C!YQY)P>D"2`G&20GY`<Y!@^'_2(N,)$@!
M``!,B<A,B<I(B?=,"=A,(=I(P>\;3`'I3"'`2`G03`'138G"2`'!2(GP2<'@
M'DC!X`5)P>H"2`G'30G"`<]!@^+_2(N,)%`!``!,B=!,B=))B?A,"<A,(<I)
MP>@;3`'I2"'P2`G03`'928GS2`'!2(GX2,'@!4D)P$$!R$C!YAY)P>L"20GS
M2(N,)%@!``!,B<9!@^/_2,'N&TR)V$R)VDP!Z4P)T$PATDP!R4@A^$F)^4@)
MT$C!YQY)P>D"2`'!20GY3(G`08/A_TP#K"1@`0``2,'@!4@)QDR)R$R)RDP)
MV$PAV@'.3"'`2(GW2`G030'52,'O&TD!Q4B)\$V)PDC!X`5)P>`>2<'J`D@)
MQTB+E"1H`0``1`'O30G"28GP08/B_TB)^4G!Z`),B=!,`>)(P>D;3#'(3`':
M2#'P2,'F'D@!PDB)^$D)\$C!X`5!@^#_2`G!3(G``=%(BY0D<`$``$PQT$@Q
M^$B)SDC![AM,`>),`<I)B?E(P><>2`'"2(G(2<'I`DC!X`5)"?E("<9!@^'_
M`=9(BY0D>`$``$R)R$PQP$B)]T@QR$P!XDP!TDF)RD@!PDB)\$C![QM(P>`%
M2,'A'DG!Z@)("<=)"<H!UTB+E"2``0``08/B_TR)T$B)^4PQR$C!Z1M,`>)(
M,?!,`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)"?!("<%!@^#_`=%(BY0DB`$`
M`$R)P$PQT$B)SD@Q^$C![AM,`>),`<I)B?E(P><>2`'"2(G(2<'I`DC!X`5)
M"?E("<8!UDB+E"20`0``08/A_TR)R$B)]TPQP$C![QM,`>)(,<A,`=))B<I(
MP>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_`==(BY0DF`$``$R)T$PQR$B)
M^4@Q\$C!Z1M,`>),`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)"?!("<%!@^#_
M`=%(BY0DH`$``$R)P$PQT$B)SD@Q^$C![AM,`>),`<I)B?E(`<)(B<A(P>`%
M2,'G'DG!Z0)("<9)"?D!UDB+E"2H`0``08/A_TR)R$B)]TPQP$C![QM,`>)(
M,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_`==(BY0DL`$`
M`$R)T$PQR$B)^4@Q\$C!Z1M,`>),`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)
M"?!("<%!@^#_`=%(BY0DN`$``$R)P$B)SDP!XDPQT$C![AM(,?A,`<I)B?E(
M`<)(B<A(P><>2,'@!4G!Z0)("<9)"?D!UDB+E"3``0``08/A_TR)R$B)]TPQ
MP$C![QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_
M`==(BY0DR`$``$R)T$PQR$B)^4@Q\$C!Z1M,`>),`<))B?!(`<)(B?A(P>`%
M2`G!2,'F'DG!Z`(!T4D)\$B+E"30`0``08/@_TB)SDR)P$C![AM,`>),,=!(
M,?A,`<I)B?E(`<)(B<A(P><>2,'@!4G!Z0)("<9)"?D!UDB+E"38`0``08/A
M_TR)R$B)]TF)\TPQP$C![QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!
MX`5)"<I("<=!@^+_`==(BY0DX`$``$R)T$B)^4B)^TP!XDP!PDPQR$C!Z1M(
M,?!)P>L"2,'F'D@!PDB)^$D)\TC!X`5!@^/_2,'K`D@)P4R)V`'12(N4).@!
M``!,,=!(,?A)B<A(P><>2<'H&T@)^TP!XH/C_TP!RDF)R4@!PDB)R$C!X`5)
M"<!(B=A!`=!(BY0D\`$``$PQV$@QR$R)QTR)QDC![QM,`>),`=)(`<),B<!(
MP>`%2`G'`==(P>$>2<'I`DD)R4B+E"3X`0``2,'N`D&#X?](B?E,B<A(P>D;
M3`'B2#'83`.D)``"``!,,<!,`=I)P>`>2`'"3`G&2(GX2,'@!8/F_T@)P4B)
M\$D!W$PQR`'12#'X2(G*20'$2(G(2,'B!4C!Z!M("=!$`>!$`?!(B44`2(GX
M2,'G'DC!Z`(#30A("?@#11`#=1A$`TT@2(E-"$B)11!(B7483(E-($B!Q`@"
M``!;74%<05U!7L-,B60DX$R)?"3X28G\2(E<)-!(B6PDV$F)]TR);"3H3(ET
M)/!(@^PX2(7_=24QP$B+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,BWPD,$B#
MQ#C#3(LU-Y(@`$V%]G3/#[8'A,!U!#'`ZQ<\/4B)^G3U2(/"`0^V`H3`=46)
MT$0IX$F++DB%[72E3&/H3(GS9I!,B>I,B>9(B>_H9N;__X7`=0I)C40M`(`X
M/70:2(MK"$B#PPA(A>UUU^EO____9I`\/76LZ[5,*?-(@\`!2,'[`T&)'^E6
M____#Q^``````%532(G[2(/L&$B-;"049I`QP$B)[DB)W^@#____2(7`="9(
M8T0D%$B-%,4`````2`,5>I$@`$B#P@A(BP)(A<!(B4+X=?#KR$B#Q!A;7<.0
M2(/L&#'`2(UT)!3HP/[__TB#Q!C##Q]$``!F#Q]$``!(@^P(@SW5BR``_W0+
MBP7-BR``2(/$",,QP+]H5$``Z+S___](A<!T!P^V`(3`=1,QP(D%J(L@`(L%
MHHL@`$B#Q`C#/#`/E<`/ML#KY0\?`$B#[`B______^A&Y/__,?:_T#A``$B#
MQ`CIUN;__V:02(L%V8L@`%,Q]K\!5D``2(M("$B+!:Z+(``/MU`@#[8%>XL@
M`&:!XO\!@^!_P>('"<)FB5$"2(L%HXL@`$B+6`CH_N7__TB)0RA(BP6/BR``
M2(M0"$B+!72+(`!(B4(P2(L%>8L@`#'22(M("$B+!02,(`!(A<!T!TB+D*@`
M``!(B5$X2(L%58L@`$B+0`A(QT!``````$B+!4*+(`!(BT`(2,=`(`````!(
MBP4OBR``2(M0"$B+!2R+(`!(B4)(6\,/'X``````#Q^``````$R)9"3H2(E<
M)-A)B?Q(B6PDX$R);"3P3(ET)/A(@>RH````2(7_=`6`/P!U,TB+G"2`````
M2(NL)(@```!,BZ0DD````$R+K"28````3(NT)*````!(@<2H````PP\?`.BO
MY/__2(7`2(G%=,`/'P!(B>_HK.+__TB%P`^$H0```$B-6`B_<U1``+D"````
M_$B)WO.F=-F_<E1``+D#````2(G>\Z9TR$R)Y^@DX___2(G?28G%Z!GC__]!
MC40%`DAC^.A\X?__2(G92(G'28G%3(GBOG540``QP.BTXO__2(GF3(GOZ$GB
M__^#P`%T$0^W1"0()0#P```]`$```'0V3(GOZ`OB__],B>_HD^3__TB)[^@+
MXO__2(7`#X5?____2(GOZ+KD__],B>?H,N/__^GV_O__3(GOZ,'^__^0Z\</
M'X``````#Q^``````%-(B?M(@\2`2(GFZ-3B__^%P'48#[=$)`@E`/```#T`
M0```=`\]`*```'0(2(/L@#'`6\-(B=^^`@```.@CX___A<`/E,!(@^R`6P^V
MP,.02(E<).A(B6PD\$R)9"3X2('L.`@``$B-G"00!```2(L%6XD@`$B)A"08
M"```,<#H<./__[D55D``B<*^>U1``#'`2(G?Z*KA__^%P'DV,>U(BY0D&`@`
M`$@S%2&)(`!(B>AU8$B+G"0@"```2(NL)"@(``!,BZ0D,`@``$B!Q#@(``##
M2(G?N@`$``!(B>;H4.#__X7`B<-XM(UX`4AC_^C_W___2(7`=*1(8]M(B<5(
MB>9(B=I(B<?HQN+__\8$*P#KC.AKXO__#Q^``````.DK____#Q]$``!F#Q]$
M``!!5S'`059)B?Y!54%454B)]5-(@^P8@#X]#Y3`2`'%2(GOZ"WA__](C70D
M%$&)QTR)]S'`Z+?Z__](A<!(B<-T-TB)Q^@+X?__1(GZ2#G0#X*\````#[9%
M`$B#Q0&(`TB#PP&$P'7N2(/$&#'`6UU!7$%=05Y!7\-(BST!C2``13'DN!``
M``!(@S\`=!](B?I(BT((08/$`4B#P@A(A<!U[T&-1"0"2)A(P>`#BQ6.B"``
MA=(/A1`!``!(B<?'!7F((``!````Z/C>__](A<!)B<4/A!D!``!)8\1(BS6>
MC"``3(GO2(T<Q0````!(B=KH7^+__TR)+82,(`!(BP5]C"``2,=$`P@`````
M1(ED)!1!#[863(GPA-(/A8@```"+7"0412GW08U\!P)(P>,#2`,=28P@`.B(
MWO__2(7`2(D##X2I````BU0D%$B+!2V,(`!(BQ3000^V!H3`B`)T)3P]="%,
MB??K#F8/'T0``$B#QP$\/70.#[9'`4B#P@&$P(@"=>K&`CT/'X``````#[9%
M`$B#Q0&(0@%(@\(!A,!U[>F__O__@/H]#X1O____2(/``0^V"(3)#X1@____
M@/D]=>SI5O___TB)Q@\?`.B?X/__2(7`2(D%H8L@`'0026/$2(T<Q0````#I
M"____TB#Q!BX_____UM=05Q!74%>05_##Q]$``!F#Q]$``!!5T%628G^055!
M5$&\D51``%532(/L2$R+/3H8``!)B>5(QP0DD51``$C'1"0(AU1``$C'1"00
ME%1``$C'1"08BE1``$C'1"0@CU1``$C'1"0HH51``$C'1"0P`````.L>3(GV
M3(GG,<#H@OW__TV+90A)@\4(387D#X2)````,<!,B>?HA_G__TB%P$B)Q730
M@#@`=,M,B?9(B<?H`^#__TB%P'7(3(GWZ);>__],B?](B</HB][__TB-7`,!
M2(GOZ'[>__](C3P#Z.7<__])B>A(B<=(B<-,B?E,B?*^O%5``#'`Z!K>__],
MB><QP$B)WNCY_/__38ME"$F#Q0A-A>0/A7?___](@\1(6UU!7$%=05Y!7\-F
M#Q^$``````!(@^PXOZQ40`!(BP5@A2``2(E$)"@QP$B+!>H6``!(B00D2(L%
MYQ8``$B)1"0(2(L%XQ8``$B)1"002(L%WQ8``$B)1"08#[<%VQ8``&:)1"0@
M,<#H1_C__S'`O[540`#H._C__S'`O[U40`#H+_C__S'`O\940`#H(_C__S'`
MO\U40`#H%_C__S'`O]U40`#H"_C__S'`O^E40`#H__?__S'`OVA40`#H\_?_
M_S'`O_)40`#HY_?__S'`O_Q40`#HV_?__S'`OP950`#HS_?__S'`OQ-50`#H
MP_?__S'`OQQ50`#HM_?__S'`OR=50`#H^_?__TB%P'0/2(G&O_)40``QP.C'
M^___,<"_.%5``.C;]___2(7`=`](B<:_2E5``#'`Z*?[__\QP+]554``Z+OW
M__](A<!T-DB)QK_I5$``,<#HA_O__S'`OH%50`"_S51``.AV^___2(M$)"A(
M,P4*A"``=5%(@\0XPP\?`#'`OV550`#H=/?__TB%P'012(G&OVA40``QP.A`
M^___Z[=(C70D$;]V54``N0H```#\\Z9UHTB-="0;OVA40``QP.@9^___ZY#H
M9MW__V:02(/L".C+W/__B<?HY-K__S'22(7`=`-(BQ!(B=!(@\0(PP\?@```
M```/'X``````55-(B?M(@^P(2(7_=`@/MB]`A.UU$$B#Q`B_<U1``%M=Z:[;
M___H"=S__T@!V$B-4/](.=,/@YX```!(BSW^%```#[9`_P^V-T`X\'0)ZRH/
MM@HXP75F2(/J`4@YTV:0<NY(.=IU*4`Z+W2J2(/$"%M=Z5W;__\/M@)`.,9T
MXTB#Z@%(.=-R[^O89@\?1```2(/J`4@YTW,)#[8".@=FD'3N2"G:,<E(C4("
M2#T`!```=@Y(@\0(2(G(6UW#B<CKN4B#P@%(B=Z_@,5@`.A2W/__N8#%8`#K
MVDB+/6`4``#K@`\?@``````/'X``````2(E<)/!(B6PD^$B#[!A(B?OH^O[_
M_TB)Q^B2WO__2(G%,<#H"/;__X7`=`I(A=MT!8`[`'4/2(M<)`A(BVPD$$B#
MQ!C#OH-50`!(B>_H4MS__T@YQ77?2(G?2(ML)!!(BUPD"$B#Q!CI`_?__P\?
M`%-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`CHG=S__X`],H(@
M```/A"D!``"+1"0<@`VA@2```X/`!4ACR$B%R0^(2@$``/)(#RK!\@]8!75P
M``!F#RX%=7````^'3`$``$B-/,T`````Z.[;__](BW0D$$B)P4B)!7.&(`!,
MC4GX2(L&2,=!"(A50`!(B0%(BP7Z@"``2,=!&(M50`!(B4$01(M$)!S'!3>&
M(``$````08/X`7XF3(U)^+\!````N@@````/'P!(BP06@\<!2(E$"AA(@\((
M03GX?^M!C4`$OO!30`!%,<!(F$G'!,$`````BU0D'$B+/=J%(`"#P@/H9MC_
M_X7`B<-T<4B+/<6%(`#HA-K__S'`O]U40`#H=/3__TB%P'092(L]J(4@`.@7
MV/__Z'+9__^)V$B#Q"!;PTB+/9>%(`!(A?]T<.@U_O__Z]0/'P#HW]C__TB%
MP$B)QTB)!6Z%(`!T=.B;V?__Q@5`@"```.FO_O__2(L]5(4@`.@3V/__B</I
M?/___TB)R$B)RDC1Z(/B`4@)T/)(#RK`\@]8P.F>_O__OA#%8`"_A%1``#'`
MZ,[:__^_Z51``.C0\___2(7`2(G'2(D%"X4@``^%<____^E)____0+<!Z)3:
M__]!5T%6055!5$F)_+_I5$``55-(B?-(@>RH!```2(L%#8`@`$B)A"28!```
M,<#H?O/__TB++;<1``!,B>=)B<5(B>[H_=G__TB%P'0Y3(GFOP950``QP.@U
M]___2(N4))@$``!(,Q7&?R``3(G@#X4T`0``2('$J`0``%M=05Q!74%>05_#
M3(GGZ%?8__],BSUD$0``2(G?08G&3(G^Z&+7__](A<!(B<-THD&#Q@%$B70D
M#$R-M"20````#Q]$``"`.P"X<U1``$@/1-A-A>UT#TB)WDR)[^@HVO__A<!T
M?DB)W^C\U___B<%(F`^V1`/_.D4`=1V-0?](F$B-%!B0#[9"_\8"`(/I`4B#
MZ@$Z10!T[8M$)`P!R#W_`P``#X\H____38G@2(GI2(G:OKQ50`!,B?<QP.AH
MU___2(UT)!!,B??H^];__X7`=1$/MT0D&"4`\```/0"```!T&S'_3(G^Z)S6
M__](A<!(B<,/A4S____IT_[__[X!````3(GWZ#[8__^%P'743(GVOP950`#H
M^?7__TR)]^CEUO__28G$Z;3^___H.-C__P\?0`!!5TF)_[_I5$``059!54%4
M55-(@>SH@0``2(L%8'X@`$B)A"38@0``,<!(QX0DT````(Y50`!(QX0DV```
M`)-50`!(QX0DX`````````#HK?'__TB%P$B)PW0)@#@`#X6/`@``,<!(C:PD
MT````.A=^O__2(7`2(G##X3'`0``2(G?Z*W6__](C7P``>@3U?__@#L`28G%
M="9(B<4/'T``#[832(GO,<"^HU5``$B#PP%(@\4"Z#K6__^`.P!UX4B-K"2@
M````OTI50`!(QX0DH````$I50`!(QX0DJ````$-50`!(QX0DL````*A50`!(
MQX0DN````&!50`!(QX0DP````+!50`!(QX0DR`````````#K$4B+?0A(@\4(
M2(7_#X1.`0``,<#HTO#__TB%P$B)PW3@@#@`=-M(B<?H;?/__X7`=,](B=_H
MA=7__TB%P$F)Q`^$'0$``$R)Y^C1U?__3(GO2(G#Z,;5__^-A`,$!```2&/H
M2(GOZ"34__](BQ6Y#@``2(G'28G&38GI0;B#54``OKI50``QP$B)T4B)5"00
M3(GBZ$?5__^^P`$``$R)]^CZU?__@\`!#X1(`0``2(UT)"!,B??HQ-7__X7`
M=14/MT0D*"4`\```/0!````/A%@!``!)BQ=(BST-?2``3(GQOM!60``QP#'M
MZ.#4__](BY0DV($``$@S%6U\(`!(B>@/A7,"``!(@<3H@0``6UU!7$%=05Y!
M7\-(B<?HGM3__TB)PTB#Q0A(A=L/A3G^__](BWT`2(7_#X0R`@``,<#HIN__
M_TB%P'3:@#@`=<I(@\4(2(7;=-D/'P#I"O[__T4QY(`]]0P```!(QX0D\```
M`+150`"[M%5``$C'A"3X````<U1``$C'A"0``0```````$B-K"3P````=2CI
MI/[__TV%Y`^%F_[__TB+70A(A=L/A([^__](@\4(@#L`#X2!_O__2(G?Z,[Q
M__^%P'312(G?Z.;3__])B<3KQ$B)Q^CU]/__2(G?Z-'3__](B<7I^?[__^A4
MU?__@S@1#X2J_O__Z$;5__])BQ=$BP!,B?%(BSW2>R``OI!60``QP#'MZ*C3
M___IP_[__XM<)"SH6M3__SG##X67_O__#[=$)"@E_P$``#W``0``#X6"_O__
M2(GOZ#72__^_BE1``$B)Q3'`Z(+N__](A<!(B<</A`L!``#H1=/__TF+/TB)
MQNBV^O__2(7`28G$#X3O````3(GGZ(;3__^#^`-!B<`/CV4%```QP.A?[O__
MA<!U%C'V3(GGZ"72__^%P(E$)!P/A<(```"^@55``+]H5$``,<#H]/'__^BS
MU/__2(M,)!!!B<!!N0%60`!,B?*^W%5``$B)[S'`,=OHX=+__^LZZ$K4__^#
M.!$/'P!U/^A]U/__2(M,)!"#PP%!B<!!B=E,B?*^ZE5``$B)[S'`2,<$)`%6
M0`#HI=+__[[``0``2(GOZ%C3__^#P`%TM$R)]^B;U/__2(GNO^E40``QP.AH
M\?__2(GOZ'#S___I?_W__[N<54``Z?#[__^0Z)_3__]-BR?I"?___[H"````
M2,?&[O___XG'Z'32__^+?"0<2(VT)!`!``"Z!@```.B.TO__@+PD$`$```!U
M#H"\)!$!``!##X38!```BWPD'#'V,=),C:0D$($``.@QTO__OXFKS>^^_MRZ
MF+GPX=+#2,>$)!"!```!(T5G2(F\)!B!``!)@\0X2(FT)""!``!(QX0D*($`
M`'94,A!(B8PD,($``$C'A"0X@0```````$C'A"1`@0```````,>$)(B!````
M````BWPD'$B-M"00`0``N@"```#HY='__X7`08G%#XXZ`0``2(N,)#B!``!)
M8]5(BX0D0($``$B-G"00`0``C3312#G.2(FT)#B!``!(@]``2,'J'4B)A"1`
M@0``2`&4)$"!``"+E"2(@0``A=)T:>F%````#Q]$``!(BP-(C;PD$($``$&#
M[4!(B80D2($``$B+0PA)B40D"$B+0Q!)B40D$$B+0QA)B40D&$B+0R!)B40D
M($B+0RA)B40D*$B+0S!)B40D,$B+0SA(@\-`28E$)#CHL=3__T&#_3]_FTEC
MU4B)WDR)Y^A!TO__1(FL)(B!``#I"?___[A`````2&/Z2(VT)!`!```IT$F-
M/#Q!.<6)PT$/3MU,8_M,B?KH"M+__XG8`X0DB($``(/X0(F$)(B!```/A<;^
M__](C8PD$`$``$$IW4B-O"00@0``28T<#^@QU/__Z7O___^+?"0<Z$?0__](
MBYPD.($``$R+I"1`@0``2(G82,'H`X/@/TACT(/``8/X.,:$%$B!``"`#XZG
M`@``2&/XND`````Q]BG"2(V\/$B!``!(8]+HJM'__TB-O"00@0``Z,G3__](
MC;PD$($``+D'````,<#\2(/'./-(JTR)X$B-O"00@0``1(BD)(.!``!(P>@8
MB)PDAX$``$R-O"20@0``B(0D@($``$R)X$R-K"3`@0``2,'H$(B$)(&!``!,
MB>!-B?Q(P>@(B(0D@H$``$B)V$C!Z!B(A"2$@0``2(G82,'H$(B$)(6!``!(
MB=@QVTC!Z`B(A"2&@0``Z"W3__](BY0D$($``$B)T(B4),.!``!(P>@8B(0D
MP($``$B)T$C!Z!"(A"3!@0``2(G02(N4)!B!``!(P>@(B(0DPH$``$B)T(B4
M),>!``!(P>@8B(0DQ($``$B)T$C!Z!"(A"3%@0``2(G02(N4)""!``!(P>@(
MB(0DQH$``$B)T(B4),N!``!(P>@8B(0DR($``$B)T$C!Z!"(A"3)@0``2(G0
M2(N4)"B!``!(P>@(B(0DRH$``$B)T(B4),^!``!(P>@8B(0DS($``$B)T$C!
MZ!"(A"3-@0``2(G02(N4)#"!``!(P>@(B(0DSH$``$B)T(B4)-.!``!(P>@8
MB(0DT($``$B)T$C!Z!"(A"31@0``2(G02,'H"(B$)-*!``!"#[84*TR)YS'`
MOJ-50`!(@\,!28/$`N@(SO__2(/[%'7>QH0DN($```!!N0%60`!-B?A(BTPD
M$$R)\K[-54``2(GO,<#HVLW__^E"^___2)B_PU5``$F-=`3\N`4```#\2(G!
M\Z8/A7[Z__]!@_@$=!E!C4#\2(M4)!!(F$$/MD0$_SH"#X5?^O__28M?"$B%
MVP^$4OK__TB)W^C$S?__2(/X`P^&0/K__TB-=`/\O\A50`"Y!0```/SSIDP/
M1./I)?K__[HX````2&/X,?8IPDB-O#Q(@0``2&/2Z`//___I>/W__X"\)!(!
M``!!#X4:^___@+PD$P$``$,/A0S[__^`O"04`0``2`^%_OK__X"\)!4!``!%
M#X7P^O__BWPD'+H"````2,?&QO___^@AS?__BWPD'$B-M"00`0``NBD```#H
M.\W__TR-A"00`0``0;D!5D``Z=?^__\/'T``05:_S51``$%505154TB![!`$
M``#&!1UT(``!2(L%+G0@`$B)A"0(!```,<#HG^?__TB%P'0)@#@Q#X3;`0``
M,<#HFN[__[H+````O@$```"_^U5``.B:R___2(7`#X2#````,>V#/;1X(``!
M2(M`$$R+8"A^7[L(````ZRT/'P!(BW<02(L%G7@@`$B+/!CHD,[__X7`=3V#
MQ0%(@\,(C44!.05X>"``?BLQTHGN3(GGZ`[-__](A<!T&DB+./9'#01UO#'V
MN@(```#H=,[__TB)QNNOBQ5%>"``C4+_.>@/A`X!``"Z!````+X!````OP!6
M0`#H^LK__TB%P$B)PW0B2(M`$+X"5D``2(LXZ/'*__](BT,02(LX]D<.0`^%
M!P$``+H$````O@$```"_)55``.B\RO__2(7`2(G#="<QP+\&54``Z(3F__](
MA<!(B<(/A`@!``!(BT,02(G62(LXZ)W*__\QP+_I5$``Q@7#<B```$C'!:!R
M(```````Z$OF__](A<!(B06)=R``#X2E````OL`!``!(B<?HXLO__X7`=25(
MBX0D"`0``$@S!9MR(``/A1\!``!(@<00!```6UU!7$%=05[#@_@1=-:#^/]T
MT8G!2(L%2G<@`$B+%3-W(`"_>%=``$B+,#'`Z-#,__^#Z@$/CNG^__^[`0``
M`$R)YX/#`>C7R?__.1T-=R``?^WIS/[__X!X`0!FD`^$(/[__^D4_O__#Q]$
M``#HW\O__^GJ_O__2(L]YW8@`.B*\___2(7`2(D%R'8@``^%CP```+\H5T``
MZ&3,__](BP7!=B``NO\#``!(B>:_!U9``$R+,$B+0Q!,BRCH,<G__X7`B<)^
M.(/J`4ACZH`\+`!U0(72?BA(B>J^+P```$B)Y^BKRO__2(7`=!-(B>I(B>9,
MB>_H^,K__^FF_O__3(GV3(GOZ#C)__\/'T``Z9+^__](8^CKOV8/'T0``.@?
MR___2(M#$$B++3AV(`!(BSCV1PT$=#I(BW\02(GNZ"_)__^)Q4B+0Q!(BSCV
M1PT$=#!(BT<02(G"2(L%!G8@`(GIOU!70`!(BS`QP.B1R___N@(````Q]N@%
MS/__2(G'Z[FZ`@```#'VZ/3+___KQ@\?@``````/'X``````NAI60`"^A!U`
M`+\D5D``Z7#+__]F#Q]$``!F#Q]$``!(@^P(Z-?___^Y`59``$4QP+YP4$``
M2(G*OT!60`!(@\0(Z8W)__^0D)"0D)"0D)!52(GE4TB#[`A(BP70:R``2(/X
M_W05,=O_T$B+@_B_8`!(@^L(2(/X_W7M2(/$"%O)PY"02(/L".@3S/__2(/$
M",,```````!005)?0TQ%04X`+BX`)7,O)7,`+W!R;V,O)6DO)7,`3$E"4$%4
M2`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?5$5-4`!005)?1$5"54<`4$%27T-!0TA%`%!!4E]04D]'3D%-10!0
M05)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!
M3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@!005)?0TQ%04X]`#$`<&%R+0`M90`M+0!54T52`%5315).04U%
M`%-94U1%30`E,#)X`%1%35!$25(`5$U0`"]T;7`O`"5S)7,E<R5S`'!A<FP`
M+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,`05)'5@`8`'!E<FP`+W!R;V,O8W5R<')O8R]F:6QE`'!E<FQX<VDN
M8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`.@``7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````
M`````+A50```````559````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@97AE8W5T:6]N
M(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@
M5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I
M;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*
M("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D
M<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T
M:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@
M87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT
M('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H
M:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T
M:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A
M<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@
M=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@
M=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S
M<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C
M875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C
M87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP
M6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L
M"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@
M('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E
M<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF
M:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@
M("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@
M("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@
M("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*
M"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'
M5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL
M("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%2
M7T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@
M("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*
M"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA
M;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A
M=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@
M("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K
M:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A
M<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U
M9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X
M.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@
M<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A
M9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT
M;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*
M("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H
M56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@
M*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@
M("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D
M(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M
M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?
M5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E"
M.B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^
M)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@
M("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]
M/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@
M("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B![
M"B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C
M:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@
M/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@
M)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@
M('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@
M("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A
M.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT
M("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@
M,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E
M;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@
M:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@
M("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@
M("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H
M.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@
M("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI
M=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@
M6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E
M($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@
M("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@
M;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*
M("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE
M(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#
M=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@
M("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O
M=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D
M9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M
M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE
M<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![
M>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L
M;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U
M="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?
M8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@
M(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@
M("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*
M"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A
M<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@
M=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A
M9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@
M<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`
M24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I
M('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@
M("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^
M("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@
M("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A
M9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I
M('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@
M("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U
M;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L
M;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q
M)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@
M("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE
M(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6
M*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@
M("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q
M=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@
M("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@
M+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M
M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`
M05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![
M"B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@
M("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@
M("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L
M("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@
M8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@
M9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@
M("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN
M;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD
M9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@
M("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@
M("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@
M("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@
M("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H
M)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R
M:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@
M("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@
M("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O
M<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@
M("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@
M?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@
M("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES
M=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N
M;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S
M+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B
M86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E
M+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A
M:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@
M(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@
M("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F
M;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@
M)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE
M+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D
M7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B
M)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@
M("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@
M("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@
M("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@
M("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\
M1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@
M("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@
M<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@
M?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I
M;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@
M3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI
M8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@
M("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@
M("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@
M("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX
M.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@
M("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF
M("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613
M:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T
M:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N
M86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@
M("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@
M("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E
M<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER
M92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R
M<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X
M<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ
M5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,
M;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA
M;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R
M97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U
M:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R
M97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*
M("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@
M;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H
M:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P
M87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX[
M"B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*
M("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@
M(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R
M93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@
M("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@
M("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PH@("`@("`@(&UK9&ER("1S=&UP9&ER
M+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O
M<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E
M:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@
M("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@
M("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B
M=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R
M(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@
M("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@
M("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B
M*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L
M;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT
M:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%2
M7T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W
M-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?
M.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B
M)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64[
M"B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@
M96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H
M+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL
M96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N
M*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2
M.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA
M;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@
M("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@
M("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@
M)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@
M("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[
M7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@
M("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*
M"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M
M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@
M("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG
M>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@
M96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@
M('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@
M)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[
M4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*
M("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]
M"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H
M)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*
M("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B
M(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@
M("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I
M;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X[
M"@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG
M="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@
M;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`````````````
M``````#`0P$;`SO4````&0```%!L___P````8&W__Q@!``"@;?__,`$``)"#
M__]@`0``<(3__X@!``#`A/__J`$``."$___``0``,(7__]@!``!0A?__\`$`
M`""&__\(`@``<(?__R@"``#`A___2`(``)"(__]H`@``H(C__X`"``"PBO__
MN`(``-"+___P`@``D(W__P@#``#`C?__(`,``+".__]``P``((___U@#```0
MD?__>`,``,"2__^P`P``\)S__^@#``!0H/__&`0``'"@__\P!````````!0`
M`````````7I2``%X$`$##`<(D`$``"0````<````T!]``)P`````00X0A@)#
M#09"C0-+@P6,!``````````4````1````.`@0``T```````````````L````
M7````"`A0`#P%0```$(.$$8.&$(.($$.*(8%C`2-`XX"1`XP1PZX!(,&```D
M````C````!`W0`#9`````$J/`HP%7@Y`C@.-!(8&@P<`````````'````+0`
M``#P-T``3P````!!#A!!#AB#`X8"1PXP```4````U````$`X0``5`````$0.
M(``````4````[````&`X0`!-`````$0.$``````4````!`$``+`X0``>````
M`$0.$``````4````'`$``-`X0`#"`````$@.$(,"```<````-`$``*`Y0`!"
M`0```$J#!HP$60ZP`8X"C0.&!1P```!4`0``\#I``$\`````00X0@P)'#I`!
M````````'````'0!``!`.T``R0````!6#L`0C`*&`X,$```````4````E`$`
M`!`\0``%```````````````T````K`$``"`\0``%`@```$(.$$0.&(X#CP)%
M#B!"#BA!#C"&!HP%C01$#CA$#E"#!P```````#0```#D`0``,#Y``!<!````
M0@X00@X8C@./`D4.($(.*(P%C01'#C!!#CA$#H`!@P>&!@``````%````!P"
M``!0/T``O@$```!$#D``````%````#0"```004``(@````!$#A``````'```
M`$P"``!`04``X@````!!#A!!#AB#`X8"1PX@```4````;`(``#!"0`!M````
M`$X.((8"@P,<````A`(``*!"0`#P`0```$$.$$0.,(,"`````````#0```"D
M`@``D$1``*P!````0@X00@X80@X@0@XHC`6-!(X#CP))#C!!#CB#!X8&2@[@
M"0``````-````-P"``!`1D``+`H```!"#A"/`DH.&$(.($(.*$$.,$$..$<.
MH(0"@P>&!HP%C02.`P`````L````%`,``'!00`!2`P```$(.$$<.&$(.($$.
M*$$.,$<.P`B#!H8%C`2-`XX"```4````1`,``-!30``4```````````````4
M````7`,``/!30``G`````$0.$```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!``````````T"`````````0``````
M```7`@````````$`````````)0(````````!`````````#("`````````0``
M``````!6`@````````\`````````A@,````````,`````````,`;0```````
M#0````````!45$````````0`````````,`)````````%`````````.@.0```
M````!@````````!8!4````````H`````````K`0````````+`````````!@`
M````````%0````````````````````,`````````&,)@```````"````````
M`-`%````````%``````````'`````````!<`````````\!5````````'````
M`````*`40```````"`````````!0`0````````D`````````&`````````#^
M__]O`````&`40```````____;P`````"`````````/#__V\`````E!-`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````HP&````````````````````````````#J&T```````/H;0```
M````"AQ````````:'$```````"H<0```````.AQ```````!*'$```````%H<
M0```````:AQ```````!Z'$```````(H<0```````FAQ```````"J'$``````
M`+H<0```````RAQ```````#:'$```````.H<0```````^AQ````````*'4``
M`````!H=0```````*AU````````Z'4```````$H=0```````6AU```````!J
M'4```````'H=0```````BAU```````":'4```````*H=0```````NAU`````
M``#*'4```````-H=0```````ZAU```````#Z'4````````H>0```````&AY`
M```````J'D```````#H>0```````2AY```````!:'D```````&H>0```````
M>AY```````"*'D```````)H>0```````JAY```````"Z'D```````,H>0```
M````VAY```````#J'D```````/H>0```````"A]````````:'T```````"H?
M0```````.A]```````!*'T```````%H?0```````:A]```````!Z'T``````
M`(H?0```````FA]```````"J'T```````+H?0````````59`````````````
M`````!C`8```````P%=```````#_____`"1&<F5E0E-$.B!R96QE87-E+SDN
M,2XP+VQI8B]C<W4O86UD-C0O8W)T,2YC(#(Q-C,S."`R,#$P+3$R+3`Y(#(Q
M.C,Q.C(Q6B!D:6T@)``D1G)E94)31#H@<F5L96%S92\Y+C$N,"]L:6(O8W-U
M+V-O;6UO;B]C<G1B<F%N9"YC(#(Q-S,W-2`R,#$Q+3`Q+3$S(#(P.C0T.C,Q
M6B!D:6T@)`!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R
M965"4T1=```D1G)E94)31#H@<F5L96%S92\Y+C$N,"]L:6(O8W-U+V%M9#8T
M+V-R=&DN4R`R,3<Q,#4@,C`Q,2TP,2TP-R`Q-CHP-SHU,5H@:VEB("0``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&
M<F5E0E-$.B!R96QE87-E+SDN,2XP+VQI8B]C<W4O86UD-C0O8W)T;BY3(#(Q
M-S$P-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K:6(@)```+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O="YP;'0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M````````````````````````````````````````````````````"P````$`
M```"```````````"0`````````(````````5`````````````````````0``
M`````````````````!,````'`````@`````````8`D```````!@"````````
M&`````````````````````0````````````````````A````!0````(`````
M````,`)````````P`@```````"0#````````!``````````(``````````0`
M````````)P````L````"`````````%@%0```````6`4```````"0"0``````
M``4````!````"``````````8`````````"\````#`````@````````#H#D``
M`````.@.````````K`0```````````````````$````````````````````W
M````____;P(`````````E!-```````"4$P```````,P`````````!```````
M```"``````````(`````````1````/[__V\"`````````&`40```````8!0`
M``````!```````````4````"````"````````````````````%,````$````
M`@````````"@%$```````*`4````````4`$````````$``````````@`````
M````&`````````!=````!`````(`````````\!5```````#P%0```````-`%
M````````!`````L````(`````````!@`````````9P````$````&````````
M`,`;0```````P!L````````3````````````````````!```````````````
M`````&(````!````!@````````#4&T```````-0;````````\`,`````````
M``````````0`````````$`````````!M`````0````8`````````T!]`````
M``#0'P```````(0T```````````````````0````````````````````<P``
M``$````&`````````%140```````5%0````````.````````````````````
M!````````````````````'D````!`````@````````!H5$```````&A4````
M````&%\```````````````````@```````````````````"!`````0````(`
M````````@+-```````"`LP```````-0````````````````````$````````
M````````````CP````$````"`````````%BT0```````6+0```````!T`P``
M````````````````"````````````````````)D````!`````P``````````
MP&````````#`````````$`````````````````````@`````````````````
M``"@`````0````,`````````$,!@```````0P````````!``````````````
M```````(````````````````````IP````$````#`````````"#`8```````
M(,`````````(````````````````````"````````````````````*P````&
M`````P`````````HP&```````"C`````````\`$````````%``````````@`
M````````$`````````"U`````0````,`````````&,)@```````8P@``````
M``@"```````````````````(``````````@`````````O@````$````#````
M`````"#$8```````(,0````````D````````````````````"```````````
M`````````,0````(`````P````````!@Q&```````$3$````````2`4`````
M`````````````"````````````````````#)`````0``````````````````
M``````!$Q````````/<!```````````````````!````````````````````
M`0````,`````````````````````````.\8```````#2````````````````
3`````0``````````````````````
